@@ -175,7 +175,10 @@ class Node(G11nBase,MPTTModel):
         It returns node's slug
         """
         if self.page:
-            return self.page.slug
+            if self.page.regex:
+                return "%s/%s" % (self.page.slug, self.page.regex)
+            else:
+                return self.page.slug
         elif not self.hide_in_url:
             return self.name
         else:
@@ -920,4 +923,4 @@ class UrlAjax(models.Model):
     class Meta:
         verbose_name = _(u"UrlAjax")
         verbose_name_plural = _(u"UrlAjax")
-        ordering = ['name',]   
\ No newline at end of file
+        ordering = ['name',]   
