@@ -1,4 +1,5 @@
 import uwsgi
+import sys
 from threading import Thread
 
 try:
@@ -6,7 +7,6 @@ try:
 except:
     import pickle
 
-
 if uwsgi.masterpid() == 0:
     raise Exception(
         "you have to enable the uWSGI master process to use this module")
@@ -170,7 +170,12 @@ class mule_brain(object):
 
     def __call__(self):
         if uwsgi.mule_id() == self.num:
-            self.f()
+            try:
+                self.f()
+            except:
+                exc = sys.exc_info()
+                sys.excepthook(exc[0], exc[1], exc[2])
+                sys.exit(1)
 
 
 class mule_brainloop(mule_brain):
@@ -178,7 +183,12 @@ class mule_brainloop(mule_brain):
     def __call__(self):
         if uwsgi.mule_id() == self.num:
             while True:
-                self.f()
+                try:
+                    self.f()
+                except:
+                    exc = sys.exc_info()
+                    sys.excepthook(exc[0], exc[1], exc[2])
+                    sys.exit(1)
 
 
 class mule(object):
@@ -334,4 +344,4 @@ class harakiri(object):
 
     def __call__(self, f):
         self.f = f
-        return self.real_call
+        return self.real_call
\ No newline at end of file
